Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6768)

Unified Diff: chrome/browser/profiles/profile_impl.h

Issue 1794353003: Refactor ProfileInfoCache in c/b/profiles (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/profiles/profile_impl.h
diff --git a/chrome/browser/profiles/profile_impl.h b/chrome/browser/profiles/profile_impl.h
index 612a48d0939ff03f3a63b2b9823b64a2529615f3..7726bc0c7add26d0540549050de1414aa6a5db95 100644
--- a/chrome/browser/profiles/profile_impl.h
+++ b/chrome/browser/profiles/profile_impl.h
@@ -182,11 +182,11 @@ class ProfileImpl : public Profile {
void EnsureSessionServiceCreated();
#endif
- // Updates the ProfileInfoCache with data from this profile.
- void UpdateProfileSupervisedUserIdCache();
- void UpdateProfileNameCache();
- void UpdateProfileAvatarCache();
- void UpdateProfileIsEphemeralCache();
+ // Updates the ProfileAttributesStorage with the data from this profile.
+ void UpdateSupervisedUserIdInStorage();
+ void UpdateNameInStorage();
+ void UpdateAvatarInStorage();
+ void UpdateIsEphemeralInStorage();
void GetCacheParameters(bool is_media_context,
base::FilePath* cache_path,

Powered by Google App Engine
This is Rietveld 408576698